@@ -1,7 +1,6 @@
 import logging
 import logging.handlers
 
-import socket
 import traceback
 
 from requests_futures.sessions import FuturesSession
@@ -9,11 +8,14 @@ from requests_futures.sessions import FuturesSession
 session = FuturesSession()
 
 
-def bg_cb(sess, resp):
+def response_callback(resp, *args, **kwargs):
     """ Don't do anything with the response """
     pass
 
 
+session.hooks['response'] = response_callback
+
+
 class HTTPSHandler(logging.Handler):
     def __init__(self, url, fqdn=False, localname=None, facility=None):
         logging.Handler.__init__(self)
@@ -31,8 +33,8 @@ class HTTPSHandler(logging.Handler):
     def emit(self, record):
         try:
             payload = self.format(record)
-            session.post(self.url, data=payload, background_callback=bg_cb)
+            session.post(self.url, data=payload.encode("utf-8"))
         except (KeyboardInterrupt, SystemExit):
             raise
         except:
-            self.handleError(record)
\ No newline at end of file
+            self.handleError(record)
